"use strict";
const components_dateSelect_kDatePicker_day = require("./day.js");
const components_dateSelect_kDatePicker_utils = require("./utils.js");
const common_vendor = require("../../../common/vendor.js");
const KButton = () => "../k-bottom-button/KBottomButton.js";
const KBottomPopup = () => "../k-bottom-popup/KBottomPopup.js";
const _sfc_main = {
  components: { KBottomPopup, KButton },
  options: {
    virtualHost: true
  },
  props: {
    confirmText: {
      type: String,
      default: "确定"
    },
    title: {
      type: String,
      default: "请选择"
    },
    modelValue: {
      type: Boolean,
      default: false
    },
    defaultValue: {
      type: [String, Number, Array]
    },
    type: {
      type: String,
      //"day" | "month" | "year"
      default: "day"
    },
    safeArea: {
      type: Boolean,
      default: true
    },
    /** 限制开始时间 **/
    limitStartDate: {
      type: [String, Number]
    },
    /** 限制结束时间 **/
    limitEndDate: {
      type: [String, Number]
    },
    /** 格式化数据 **/
    formatter: {
      type: String
    },
    /** 是否为范围选择器 **/
    isRange: {
      type: Boolean,
      default: () => false
    },
    /** 是否为多选 **/
    multiple: {
      type: Boolean,
      default: () => false
    }
  },
  computed: {
    briefDate() {
      if (this.type === "day") {
        return this.currentDay.format("YYYY年MM月");
      }
      if (this.type === "month") {
        return this.currentDay.format("YYYY年");
      }
      if (this.type === "year") {
        return `${this.startYear.format("YYYY")} - ${this.startYear.add(9, "year").format("YYYY")}`;
      }
    },
    selectedDate() {
      const formatMap = {
        day: "YYYY-MM-DD",
        month: "YYYY-MM",
        year: "YYYY年"
      };
      const format = formatMap[this.type];
      if (this.isRange) {
        return `${this.rangeStart ? this.rangeStart.format(format) : "-"} 至 ${this.rangeEnd ? this.rangeEnd.format(format) : "-"}`;
      } else {
        if (this.checked.length > 0) {
          return this.checked.map((item) => item.format(format)).join("、");
        } else {
          return "-";
        }
      }
    },
    backText() {
      if (this.type === "day") {
        return this.currentDay.format("M");
      }
      return "";
    },
    blocks() {
      const dates = this.type === "day" ? this.days : this.type === "month" ? this.months : this.years;
      const result = [];
      const chineseMap = {
        day: (date) => {
          return date.format("D");
        },
        month: (date) => {
          return components_dateSelect_kDatePicker_utils.monthsChinese[date.month()];
        },
        year: (date) => {
          return date.format("YYYY年");
        }
      };
      for (const date of dates) {
        if (!date) {
          result.push(date);
        } else {
          const obj = {
            date,
            chinese: chineseMap[this.type](date),
            isLimit: this.limitStartDate && date.isBefore(components_dateSelect_kDatePicker_day.dayjs(this.limitStartDate)) || this.limitEndDate && date.isAfter(components_dateSelect_kDatePicker_day.dayjs(this.limitEndDate)),
            isCurrent: date.startOf(this.type).isSame(this.sameDay.startOf(this.type)),
            isSelect: this.checked.findIndex((item) => item.valueOf() === date.valueOf()) !== -1,
            isStart: this.rangeStart && date.startOf(this.type).isSame(this.rangeStart.startOf(this.type)),
            isEnd: this.rangeEnd && date.startOf(this.type).isSame(this.rangeEnd.startOf(this.type)),
            isInRange: this.rangeStart && this.rangeEnd && date.startOf(this.type).isAfter(this.rangeStart.startOf(this.type)) && date.startOf(this.type).isBefore(this.rangeEnd.startOf(this.type))
          };
          if (this.isRange) {
            obj.isSelect = obj.isStart && obj.isEnd;
          }
          result.push(obj);
        }
      }
      return result;
    },
    days() {
      const result = [];
      let start = this.currentDay.startOf("month");
      const end = this.currentDay.endOf("month");
      const firstDayWeek = start.day();
      for (let i = 0; i < firstDayWeek; i++) {
        result.push("");
      }
      while (start.isBefore(end)) {
        result.push(start);
        start = start.add(1, "day");
      }
      return result;
    },
    months() {
      const result = [];
      for (let i = 0; i < 12; i++) {
        const date = this.currentDay.startOf("year").add(i, "month");
        result.push(date);
      }
      return result;
    },
    startYear() {
      return this.currentDay.subtract(this.currentDay.year() % 10, "year");
    },
    years() {
      const result = [];
      for (let i = 0; i < 10; i++) {
        const date = this.startYear.add(i, "year");
        result.push(date);
      }
      return result;
    }
  },
  data() {
    return {
      sameDay: components_dateSelect_kDatePicker_day.dayjs(),
      // 当日
      rangeStart: null,
      // 范围选择器开始日期
      rangeEnd: null,
      // 范围选择器结束日期
      checked: [],
      // 选中的日期
      currentDay: components_dateSelect_kDatePicker_day.dayjs(),
      // 当前选择器显示的日期
      weeksChinese: components_dateSelect_kDatePicker_utils.weeksChinese,
      left: components_dateSelect_kDatePicker_utils.left,
      closable: components_dateSelect_kDatePicker_utils.closable,
      left_double: components_dateSelect_kDatePicker_utils.left_double,
      show: false
    };
  },
  methods: {
    onClick() {
      if (this.isRange) {
        const _rangeStart = this.rangeStart ? this.formatter ? this.rangeStart.format(this.formatter) : this.rangeStart.valueOf() : null;
        const _rangeEnd = this.rangeEnd ? this.formatter ? this.rangeEnd.format(this.formatter) : this.rangeEnd.valueOf() : null;
        this.$emit("change", [_rangeStart, _rangeEnd]);
      } else {
        const _checked = this.selectedDate !== "-" ? this.multiple ? this.checked.map(
          (item) => this.formatter ? item.format(this.formatter) : item.valueOf()
        ) : this.formatter ? this.checked[0].format(this.formatter) : this.checked[0].valueOf() : null;
        this.$emit("change", _checked);
      }
    },
    handleClickItem(block) {
      if (block === "" || this.limitEndDate && block.date.isAfter(components_dateSelect_kDatePicker_day.dayjs(this.limitEndDate)) || this.limitStartDate && block.date.isBefore(components_dateSelect_kDatePicker_day.dayjs(this.limitStartDate)))
        return;
      if (this.isRange) {
        if (this.rangeStart && this.rangeEnd && !block.isStart && !block.isEnd) {
          this.rangeStart = block.date;
          this.rangeEnd = null;
          return;
        }
        if (block.isSelect) {
          this.rangeStart = null;
          this.rangeEnd = null;
          return;
        }
        if (block.isStart) {
          if (!this.rangeEnd) {
            this.rangeEnd = block.date;
            return;
          }
          this.rangeStart = null;
          return;
        }
        if (block.isEnd) {
          this.rangeEnd = null;
          return;
        }
        const setStartAndEndDay = (start) => {
          if (block.date.isBefore(start)) {
            this.rangeEnd = start;
            this.rangeStart = block.date;
          } else {
            this.rangeEnd = block.date;
          }
        };
        if (this.rangeStart) {
          setStartAndEndDay(this.rangeStart);
        } else {
          if (this.rangeEnd) {
            setStartAndEndDay(this.rangeEnd);
          } else {
            this.rangeStart = block.date;
          }
        }
      } else {
        if (block.isSelect) {
          this.checked = this.checked.filter((item) => item.valueOf() !== block.date.valueOf());
          return;
        }
        this.multiple ? this.checked.push(block.date) : this.checked = [block.date];
      }
    },
    toggle(type, direction) {
      if (this.type === "day") {
        this.currentDay = this.currentDay.add(
          direction === "left" ? -1 : 1,
          type === "single" ? "month" : "year"
        );
      }
      if (this.type === "month") {
        this.currentDay = this.currentDay.add(direction === "left" ? -1 : 1, "year");
      }
      if (this.type === "year") {
        this.currentDay = this.currentDay.add(direction === "left" ? -10 : 10, "year");
      }
    },
    close() {
      this.$emit("update:modelValue", false);
    },
    init() {
      if (!["day", "month", "year"].includes(this.type)) {
        console.error("类型必须为 day | month | year");
        return;
      }
      if (this.isRange && this.multiple) {
        console.error("目前暂不支持时间段的多选");
        return;
      }
      this.checked = [];
      this.rangeStart = null;
      this.rangeEnd = null;
      if (!this.defaultValue)
        return;
      if (this.isRange) {
        if (!Array.isArray(this.defaultValue) || this.defaultValue.length !== 2) {
          console.error("区间选择器的默认值必须为长度为2的数组");
          return;
        }
        this.currentDay = components_dateSelect_kDatePicker_day.dayjs(this.defaultValue[0]);
        this.rangeStart = components_dateSelect_kDatePicker_day.dayjs(this.defaultValue[0]);
        this.rangeEnd = components_dateSelect_kDatePicker_day.dayjs(this.defaultValue[1]);
      } else {
        if (this.multiple && Array.isArray(this.defaultValue)) {
          this.checked = this.defaultValue.map((item) => components_dateSelect_kDatePicker_day.dayjs(item));
        } else {
          this.checked = [components_dateSelect_kDatePicker_day.dayjs(this.defaultValue)];
        }
        this.currentDay = this.checked[0] ? components_dateSelect_kDatePicker_day.dayjs(this.checked[0]) : components_dateSelect_kDatePicker_day.dayjs();
      }
    }
  },
  mounted() {
    this.init();
  },
  watch: {
    modelValue: {
      handler(value) {
        this.show = !!value;
      }
    },
    show: {
      handler(value) {
        this.$emit("update:modelValue", value);
      }
    },
    type: {
      handler() {
        this.init();
      }
    },
    defaultValue: {
      handler() {
        this.init();
      },
      deep: true
    }
  }
};
if (!Array) {
  const _component_KButton = common_vendor.resolveComponent("KButton");
  const _component_KBottomPopup = common_vendor.resolveComponent("KBottomPopup");
  (_component_KButton + _component_KBottomPopup)();
}
function _sfc_render(_ctx, _cache, $props, $setup, $data, $options) {
  return common_vendor.e({
    a: common_vendor.t($props.title),
    b: $data.closable,
    c: common_vendor.o((...args) => $options.close && $options.close(...args)),
    d: $props.type === "day"
  }, $props.type === "day" ? {
    e: $data.left_double,
    f: common_vendor.o(($event) => $options.toggle("double", "left"))
  } : {}, {
    g: $data.left,
    h: common_vendor.o(($event) => $options.toggle("single", "left")),
    i: common_vendor.t($options.briefDate),
    j: $data.left,
    k: common_vendor.o(($event) => $options.toggle("single", "right")),
    l: $props.type === "day"
  }, $props.type === "day" ? {
    m: $data.left_double,
    n: common_vendor.o(($event) => $options.toggle("double", "right"))
  } : {}, {
    o: $props.type === "day"
  }, $props.type === "day" ? {
    p: common_vendor.f($data.weeksChinese, (item, index, i0) => {
      return {
        a: common_vendor.t(item),
        b: index
      };
    }),
    q: $props.isRange ? "0" : "12rpx"
  } : {}, {
    r: common_vendor.f($options.blocks, (block, index, i0) => {
      return {
        a: common_vendor.t(block.chinese || ""),
        b: block.isCurrent ? 1 : "",
        c: block.isStart ? 1 : "",
        d: block.isEnd ? 1 : "",
        e: block.isInRange ? 1 : "",
        f: block.isSelect ? 1 : "",
        g: block.isLimit ? 1 : "",
        h: index,
        i: common_vendor.o(($event) => $options.handleClickItem(block), index)
      };
    }),
    s: $props.type === "day" ? 1 : "",
    t: $props.type === "month" ? 1 : "",
    v: $props.type === "year" ? 1 : "",
    w: $options.backText,
    x: $props.isRange ? "0" : "12rpx",
    y: !$props.multiple
  }, !$props.multiple ? {
    z: common_vendor.t($options.selectedDate)
  } : {}, {
    A: common_vendor.o($options.onClick),
    B: common_vendor.p({
      label: $props.confirmText,
      ["box-shadow"]: false,
      ["safe-area"]: $props.safeArea
    }),
    C: common_vendor.o(($event) => $data.show = $event),
    D: common_vendor.p({
      modelValue: $data.show
    })
  });
}
const Component = /* @__PURE__ */ common_vendor._export_sfc(_sfc_main, [["render", _sfc_render], ["__file", "F:/WorkCode/CNBG/cnbg_mp/src/components/dateSelect/k-date-picker/KDatePicker.vue"]]);
wx.createComponent(Component);
