"use strict";
const common_vendor = require("../../../common/vendor.js");
const utils_index = require("../../../utils/index.js");
const store_login = require("../../../store/login.js");
const mp_ecard_sdk_main = require("../../../mp_ecard_sdk/main.js");
const service_modules_auth = require("../../../service/modules/auth.js");
function useAuthFn(userInfo, radioValue, certList) {
  const loginStore = store_login.useLoginStore();
  const checkInfo = () => {
    if (!userInfo.realname) {
      common_vendor.index.showToast({
        title: "请输入姓名",
        icon: "none"
      });
      return;
    }
    if (!userInfo.idCardNumber) {
      common_vendor.index.showToast({
        title: "请输入身份证号",
        icon: "none"
      });
      return;
    }
    if (!utils_index.isValidChineseIDNumber(userInfo.idCardNumber)) {
      common_vendor.index.showToast({
        title: "请输入正确的身份证号",
        icon: "none"
      });
      return;
    }
    if (!utils_index.isValidBankCard(userInfo.bankCardNumber)) {
      common_vendor.index.showToast({
        title: "请检查银行卡号",
        icon: "none"
      });
      return;
    }
    if (!utils_index.isValidPhoneNumber(userInfo.bankPhone)) {
      common_vendor.index.showToast({
        title: "请检查银行绑定手机号",
        icon: "none"
      });
      return;
    }
    if (!radioValue.value) {
      common_vendor.index.showToast({
        title: "请选择认证渠道",
        icon: "none"
      });
      return;
    }
    return true;
  };
  const saveBaseInfo = async () => {
    const data = {
      userId: loginStore.currentUserInfo.userId,
      realname: userInfo.realname,
      idCardNumber: userInfo.idCardNumber,
      bankCardNumber: userInfo.bankCardNumber,
      bankPhone: userInfo.bankPhone,
      subjectLocation: radioValue.value
    };
    common_vendor.index.showLoading({
      title: "保存信息中",
      mask: true
    });
    const res = await service_modules_auth.saveBaseInfoApi(data);
    if (res.code === 0) {
      loginStore.getUserInfoByCode();
    }
    common_vendor.index.hideLoading();
  };
  const signCertFn = async () => {
    var _a;
    common_vendor.index.showLoading({
      title: "信息校验中",
      icon: "loading",
      mask: true
    });
    const data = {
      userId: loginStore.currentUserInfo.userId,
      subjectLocation: radioValue.value
    };
    const res = await service_modules_auth.signCertApi(data);
    common_vendor.index.hideLoading();
    if (res.code === 0) {
      if (((_a = res.data) == null ? void 0 : _a.certStatus) === "SIGNING") {
        signCertFn();
      } else {
        signAgreementFn();
      }
    } else {
      setTimeout(() => {
        common_vendor.index.showToast({
          title: res.msg || "失败，请重试",
          icon: "none"
        });
      }, 0);
    }
  };
  const agereementModal = common_vendor.ref();
  const agreemetChecked = common_vendor.ref(false);
  const signAgreementFn = () => {
    if (certList.value) {
      const curr = certList.value.find((item) => item.subjectLocation === radioValue.value);
      if (curr == null ? void 0 : curr.agreementUrl) {
        getETokenAndToVerify();
        return;
      }
      agereementModal.value.open();
    }
  };
  const agreementUrl = common_vendor.ref("");
  const signAgreeSuccess = async () => {
    common_vendor.index.showLoading({
      title: "提交信息中",
      mask: true
    });
    const data = {
      userId: loginStore.currentUserInfo.userId,
      agreementUrl: agreementUrl.value,
      subjectLocation: radioValue.value
    };
    const res = await service_modules_auth.signAgreementApi(data);
    if (res.code === 0) {
      getETokenAndToVerify();
    } else {
      common_vendor.index.showToast({
        title: res.msg || "签署失败",
        icon: "none",
        duration: 1500
      });
      common_vendor.index.navigateBack();
    }
    common_vendor.index.hideLoading();
  };
  const getETokenAndToVerify = async () => {
    if (loginStore.currentUserInfo.existEidResult) {
      authCertFn();
      return;
    }
    const data = {
      realName: userInfo.realname,
      idCard: userInfo.idCardNumber
    };
    const res = await service_modules_auth.getETokenApi(data);
    if (res.code === 0) {
      const etoken = res.data;
      const param = {
        data: {
          token: etoken
        },
        verifyDoneCallback(res2) {
          console.log("收到核身完成的res", res2);
        }
      };
      etoken && mp_ecard_sdk_main.startEid(param);
    } else {
      common_vendor.index.showToast({
        title: "状态获取失败，请重试",
        icon: "none"
      });
    }
  };
  const authBackHandler = async (options) => {
    if ((options == null ? void 0 : options.path) !== "mp_ecard_sdk/index/index")
      return;
    const { referrerInfo, scene } = options;
    if (scene === 1038 && (referrerInfo == null ? void 0 : referrerInfo.appId) === "wx0e2cb0b052a91c92") {
      const { extraData } = referrerInfo;
      if (!extraData) {
        return common_vendor.index.showToast({
          title: "核身失败，请重试",
          icon: "none",
          duration: 3e3
        });
      }
      const { token, verifyDone } = extraData;
      if (verifyDone) {
        common_vendor.index.showLoading({
          title: "核身结果获取中",
          mask: true
        });
        const res = await service_modules_auth.getETokenResultApi(token);
        common_vendor.index.hideLoading();
        if (res.code === 0) {
          if (res.data.compareCode === 0) {
            common_vendor.index.showToast({
              title: "核身成功",
              icon: "none"
            });
            authCertFn();
          } else {
            common_vendor.index.showToast({
              title: "核身失败",
              icon: "none"
            });
          }
        } else {
          common_vendor.index.showToast({
            title: res.msg || "未查询到结果",
            icon: "none"
          });
        }
      }
    }
    console.log("options", options);
  };
  const authCertFn = async () => {
    const data = {
      userId: loginStore.currentUserInfo.userId,
      subjectLocation: radioValue.value,
      token: loginStore.currentUserInfo.certToken
    };
    const res = await service_modules_auth.batchCertApi(data);
    if (res.code === 0) {
      saveBankInfo();
    } else {
      common_vendor.index.showToast({
        title: res.msg || "提交失败，请重试",
        icon: "none",
        duration: 3e3
      });
    }
    loginStore.getUserInfoByCode();
  };
  const saveBankInfo = async () => {
    const data = {
      userId: loginStore.currentUserInfo.userId,
      bankPhone: loginStore.currentUserInfo.bankPhone,
      bankCardNumber: loginStore.currentUserInfo.bankCardNumber
    };
    const res = await service_modules_auth.saveBankInfoApi(data);
    if (res.code === 0) {
      common_vendor.index.showToast({
        title: "成功",
        icon: "none",
        duration: 3e3
      });
    }
  };
  return {
    checkInfo,
    saveBaseInfo,
    signCertFn,
    signAgreementFn,
    authCertFn,
    signAgreeSuccess,
    authBackHandler,
    agereementModal,
    agreemetChecked,
    agreementUrl
  };
}
exports.useAuthFn = useAuthFn;
