"use strict";
const common_vendor = require("../../common/vendor.js");
const wxUtils_index = require("../../wxUtils/index.js");
const store_task = require("../../store/task.js");
const service_modules_getTask = require("../../service/modules/getTask.js");
const utils_index = require("../../utils/index.js");
require("../../service/index.js");
const _sfc_main = /* @__PURE__ */ common_vendor.defineComponent({
  __name: "index",
  setup(__props) {
    const taskStore = store_task.useTask();
    const { ctx } = common_vendor.getCurrentInstance();
    common_vendor.ref();
    const latitud = common_vendor.reactive({
      latitude: 39.909,
      longitude: 116.39742
    });
    const markers = common_vendor.ref([]);
    const circles = common_vendor.ref([]);
    const myMap = common_vendor.ref();
    const taskFiledKey = common_vendor.ref();
    common_vendor.onLoad(async (e) => {
      taskFiledKey.value = e == null ? void 0 : e.taskFiledKey;
      myMap.value = common_vendor.index.createMapContext("myMap", ctx);
      await getDictPoint();
      await getLocation();
    });
    const getLocation = async () => {
      try {
        const res = await wxUtils_index.getWxLocationApi();
        latitud.latitude = res == null ? void 0 : res.latitude;
        latitud.longitude = res == null ? void 0 : res.longitude;
        setMapRegion();
        await getPointSignInfo();
      } catch (e) {
        common_vendor.index.showToast({
          title: "获取定位失败",
          icon: "none"
        });
        console.log(e);
      }
    };
    const mapRadius = common_vendor.ref();
    const getDictPoint = async () => {
      const res = await service_modules_getTask.getDictPointApi();
      mapRadius.value = res.data[0].value;
    };
    const setMapRegion = () => {
      myMap.value.getRegion({
        success() {
          circles.value.push({
            latitude: latitud.latitude,
            longitude: latitud.longitude,
            color: "#ffffff",
            fillColor: "#7cb5ec88",
            radius: Number(mapRadius.value),
            strokeWidth: 2
          });
        }
      });
    };
    const hospitalList = common_vendor.ref([]);
    const getPointSignInfo = async () => {
      common_vendor.index.showLoading({
        title: "加载中"
      });
      const res = await service_modules_getTask.getPointSignInfoApi(latitud);
      hospitalList.value = res.data;
      common_vendor.index.hideLoading();
      calcDistance();
    };
    const curentDistance = common_vendor.ref();
    async function calcDistance() {
      //! 数据处理
      if (!hospitalList.value.length)
        return;
      let hospitalMap = hospitalList.value.map((item) => {
        item.distance = utils_index.getDistance(
          latitud.longitude,
          latitud.latitude,
          item.longitude,
          item.latitude
        );
        return item;
      });
      hospitalMap.sort((itemA, itemB) => {
        return itemA.distance - itemB.distance > 0 ? 1 : -1;
      });
      hospitalList.value = hospitalMap;
      curentDistance.value = hospitalMap[0];
      setMarkers(curentDistance.value);
      checkSignInState();
    }
    const setMarkers = (distanceItem) => {
      markers.value = [
        {
          id: Number(distanceItem.signEntId),
          latitude: distanceItem.latitude,
          longitude: distanceItem.longitude,
          width: 25,
          height: 35,
          callout: {
            display: "BYCLICK",
            content: distanceItem.signEntName,
            color: "black",
            borderRadius: 8,
            bgColor: "#ffffff",
            padding: 10,
            textAlign: "center"
          }
        }
      ];
    };
    const withinTheScopeOf = common_vendor.ref(false);
    const locationList = common_vendor.ref([]);
    const checkSignInState = () => {
      var _a, _b;
      let result = utils_index.getDistance(
        latitud.longitude,
        latitud.latitude,
        (_a = curentDistance == null ? void 0 : curentDistance.value) == null ? void 0 : _a.longitude,
        (_b = curentDistance == null ? void 0 : curentDistance.value) == null ? void 0 : _b.latitude
      );
      result = result * 1e3;
      withinTheScopeOf.value = mapRadius.value >= result;
      locationList.value = hospitalList.value.filter((item) => {
        let itemResult = utils_index.getDistance(latitud.longitude, latitud.latitude, item.longitude, item.latitude);
        itemResult = itemResult * 1e3;
        if (mapRadius.value > itemResult) {
          item.value = item.signEntId;
          item.label = item.signEntName;
          return item;
        }
      });
    };
    const act = common_vendor.ref(0);
    const visitScroll = (event) => {
      let curr = event.detail.value[0];
      act.value = curr;
      curentDistance.value = locationList.value[curr];
      setMarkers(curentDistance.value);
    };
    const toDetail = () => {
      var _a;
      const address = (_a = curentDistance.value) == null ? void 0 : _a.signEntName;
      if (!address) {
        return common_vendor.index.showToast({
          title: "您当前范围内没有可打卡终端",
          icon: "none"
        });
      }
      const obj = {
        sendParamsKey: taskFiledKey.value,
        value: address
      };
      taskStore.setLocationSelect(obj);
      common_vendor.index.navigateBack();
    };
    common_vendor.onUnmounted(() => {
    });
    return (_ctx, _cache) => {
      return {
        a: latitud.latitude,
        b: latitud.longitude,
        c: markers.value,
        d: circles.value,
        e: common_vendor.f(locationList.value, (item, index, i0) => {
          return {
            a: common_vendor.t(item.signEntName),
            b: common_vendor.t(item.dis),
            c: index,
            d: act.value === index ? 1 : ""
          };
        }),
        f: common_vendor.o(visitScroll),
        g: common_vendor.o(toDetail)
      };
    };
  }
});
const MiniProgramPage = /* @__PURE__ */ common_vendor._export_sfc(_sfc_main, [["__scopeId", "data-v-214a8c10"], ["__file", "F:/WorkCode/CNBG/cnbg_mp/src/pages-sub-task/location-select/index.vue"]]);
wx.createPage(MiniProgramPage);
