"use strict";
const common_vendor = require("../../common/vendor.js");
const wxUtils_index = require("../../wxUtils/index.js");
const utils_index = require("../../utils/index.js");
const store_task = require("../../store/task.js");
const service_modules_getTask = require("../../service/modules/getTask.js");
require("../../service/index.js");
const _sfc_main = /* @__PURE__ */ common_vendor.defineComponent({
  __name: "index",
  setup(__props) {
    const useTaskStore = store_task.useTask();
    const { ctx } = common_vendor.getCurrentInstance();
    common_vendor.ref();
    const latitud = common_vendor.reactive({
      latitude: 39.909,
      longitude: 116.39742
    });
    const markers = common_vendor.ref([]);
    const circles = common_vendor.ref([]);
    const myMap = common_vendor.ref();
    const taskTypeId = common_vendor.ref("");
    const title = common_vendor.ref("");
    const timer = common_vendor.ref();
    common_vendor.onLoad(async (e) => {
      title.value = e == null ? void 0 : e.title;
      taskTypeId.value = e == null ? void 0 : e.value;
      myMap.value = common_vendor.index.createMapContext("myMap", ctx);
      await getDictPoint();
    });
    const getLocation = async () => {
      try {
        const res = await wxUtils_index.getWxLocationApi();
        const { latitude, longitude } = res || {};
        if (latitud.latitude !== latitude || latitud.longitude !== longitude) {
          latitud.latitude = latitude;
          latitud.longitude = longitude;
          flag.value = true;
          setMapRegion();
          await fetchHospitalList();
        }
      } catch (err) {
        handleLocationError();
      }
    };
    const fetchHospitalList = async () => {
      try {
        await getPointSignInfo();
      } catch (err) {
        console.error("获取终端失败，请联系管理员");
      }
    };
    const handleLocationError = () => {
      flag.value = false;
      if (timer.value) {
        clearInterval(timer.value);
        timer.value = null;
      }
      common_vendor.index.showModal({
        title: "错误提示",
        showCancel: false,
        content: "获取定位失败"
      });
    };
    const mapRadius = common_vendor.ref();
    const getDictPoint = async () => {
      common_vendor.index.showLoading();
      const res = await service_modules_getTask.getDictPointApi();
      mapRadius.value = res.data[0].value;
      common_vendor.index.hideLoading();
    };
    const setMapRegion = () => {
      myMap.value.getRegion({
        success() {
          circles.value.push({
            latitude: latitud.latitude,
            longitude: latitud.longitude,
            color: "#ffffff",
            fillColor: "#7cb5ec88",
            radius: Number(mapRadius.value),
            strokeWidth: 2
          });
        }
      });
    };
    const hospitalList = common_vendor.ref([]);
    const getPointSignInfo = async () => {
      const res = await service_modules_getTask.getPointSignInfoApi(latitud);
      hospitalList.value = res.data;
      calcDistance();
    };
    const curentDistance = common_vendor.ref();
    async function calcDistance() {
      //! 数据处理
      if (!hospitalList.value.length)
        return;
      let hospitalMap = hospitalList.value.map((item) => {
        item.distance = utils_index.getDistance(
          latitud.longitude,
          latitud.latitude,
          item.longitude,
          item.latitude
        );
        return item;
      });
      hospitalMap.sort((itemA, itemB) => {
        return itemA.distance - itemB.distance > 0 ? 1 : -1;
      });
      hospitalList.value = hospitalMap;
      curentDistance.value = hospitalMap[0];
      getsignTempResult();
      setMarkers(curentDistance.value);
      checkSignInState();
    }
    const setMarkers = (distanceItem) => {
      markers.value = [
        {
          id: Number(distanceItem.signEntId),
          latitude: distanceItem.latitude,
          longitude: distanceItem.longitude,
          width: 25,
          height: 35,
          callout: {
            display: "BYCLICK",
            content: distanceItem.signEntName,
            color: "black",
            borderRadius: 8,
            bgColor: "#ffffff",
            padding: 10,
            textAlign: "center"
          }
        }
      ];
    };
    const withinTheScopeOf = common_vendor.ref(false);
    const locationList = common_vendor.ref([]);
    const checkSignInState = () => {
      var _a, _b;
      let result = utils_index.getDistance(
        latitud.longitude,
        latitud.latitude,
        (_a = curentDistance == null ? void 0 : curentDistance.value) == null ? void 0 : _a.longitude,
        (_b = curentDistance == null ? void 0 : curentDistance.value) == null ? void 0 : _b.latitude
      );
      result = result * 1e3;
      withinTheScopeOf.value = mapRadius.value >= result;
      locationList.value = hospitalList.value.filter((item) => {
        let itemResult = utils_index.getDistance(latitud.longitude, latitud.latitude, item.longitude, item.latitude);
        itemResult = itemResult * 1e3;
        if (mapRadius.value > itemResult) {
          item.value = item.signEntId;
          item.label = item.signEntName;
          return item;
        }
      });
    };
    const act = common_vendor.ref(0);
    const visitScroll = (event) => {
      let curr = event.detail.value[0];
      act.value = curr;
      curentDistance.value = locationList.value[curr];
      getSignInfo();
      setMarkers(curentDistance.value);
    };
    const getSignInfo = utils_index.debounce(() => {
      getsignTempResult();
    }, 500);
    const getsignTempResult = async () => {
      var _a;
      common_vendor.index.showLoading({
        mask: true,
        title: "获取签到信息中"
      });
      const obj = {
        locationId: (_a = curentDistance.value) == null ? void 0 : _a.signEntId,
        taskTypeId: taskTypeId.value,
        combine: true,
        signTime: common_vendor.dayjs().format("YYYY-MM-DD HH:mm:ss")
      };
      const res = await service_modules_getTask.getSignTempResultApi(obj);
      if (res.data) {
        notClockedIn.value = false;
        signResultTime.value = res.data;
      } else {
        notClockedIn.value = true;
        signResultTime.value = "";
      }
      common_vendor.index.hideLoading();
    };
    const notClockedIn = common_vendor.ref(true);
    const signResultTime = common_vendor.ref("");
    const signFn = async () => {
      var _a;
      if (!curentDistance.value) {
        return common_vendor.index.showToast({
          title: "请选择签到地点",
          icon: "none"
        });
      }
      const obj = {
        locationId: (_a = curentDistance.value) == null ? void 0 : _a.signEntId,
        taskTypeId: taskTypeId.value,
        combine: true,
        signTime: common_vendor.dayjs().format("YYYY-MM-DD HH:mm:ss")
      };
      const res = await service_modules_getTask.signTempApi(obj);
      if (res.code === 0) {
        common_vendor.index.showToast({
          title: "签到成功",
          icon: "none"
        });
        notClockedIn.value = false;
        signResultTime.value = res.data;
      }
    };
    let flag = common_vendor.ref(false);
    common_vendor.onShow(async () => {
      Lock.value = false;
      await getLocation();
      if (flag.value) {
        timer.value = setInterval(() => {
          getLocation();
        }, 60 * 1e3);
      }
    });
    const Lock = common_vendor.ref(false);
    const toDetail = () => {
      var _a, _b, _c, _d, _e;
      if (Lock.value)
        return;
      common_vendor.index.showLoading({
        mask: true,
        title: "加载中"
      });
      Lock.value = true;
      let TIME = 15;
      const signOutTime = common_vendor.dayjs(signResultTime.value);
      const currentTime = common_vendor.dayjs();
      if (currentTime.diff(signOutTime, "minute") > TIME) {
        const data = {
          address: (_a = curentDistance.value) == null ? void 0 : _a.signEntName,
          locationId: (_b = curentDistance.value) == null ? void 0 : _b.signEntId,
          signTime: signResultTime.value,
          signEntType: (_c = curentDistance.value) == null ? void 0 : _c.signEntType,
          longitude: (_d = curentDistance.value) == null ? void 0 : _d.longitude,
          latitude: (_e = curentDistance.value) == null ? void 0 : _e.latitude,
          checkOutTime: common_vendor.dayjs().format("YYYY-MM-DD HH:mm:ss")
        };
        useTaskStore.setSignAddressInfo(data);
        common_vendor.index.navigateTo({
          url: `/pages-sub-task/task/index?value=${taskTypeId.value}&title=${title.value}`
        });
        common_vendor.index.hideLoading();
        setTimeout(() => {
          Lock.value = false;
        }, 3e3);
      } else {
        common_vendor.index.showToast({
          title: `签到和签退时间间隔不可少于${TIME}分钟。`,
          icon: "none"
        });
      }
    };
    common_vendor.onUnmounted(() => {
      if (timer.value) {
        clearInterval(timer.value);
      }
    });
    return (_ctx, _cache) => {
      return common_vendor.e({
        a: latitud.latitude,
        b: latitud.longitude,
        c: markers.value,
        d: circles.value,
        e: common_vendor.f(locationList.value, (item, index, i0) => {
          return {
            a: common_vendor.t(item.signEntName),
            b: common_vendor.t(item.dis),
            c: index,
            d: act.value === index ? 1 : ""
          };
        }),
        f: common_vendor.o(visitScroll),
        g: notClockedIn.value
      }, notClockedIn.value ? {
        h: common_vendor.o(signFn)
      } : {
        i: common_vendor.o(toDetail)
      }, {
        j: !notClockedIn.value
      }, !notClockedIn.value ? {
        k: common_vendor.t(signResultTime.value)
      } : {});
    };
  }
});
const MiniProgramPage = /* @__PURE__ */ common_vendor._export_sfc(_sfc_main, [["__scopeId", "data-v-f4795ef1"], ["__file", "F:/WorkCode/CNBG/cnbg_mp/src/pages-sub-task/location/index.vue"]]);
wx.createPage(MiniProgramPage);
