"use strict";
const common_vendor = require("../common/vendor.js");
const service_modules_common = require("../service/modules/common.js");
const service_modules_login = require("../service/modules/login.js");
const service_modules_newsDetail = require("../service/modules/newsDetail.js");
const useLoginStore = common_vendor.defineStore("login", {
  state() {
    return {
      accessToken: "",
      userInfo: [],
      currentUserId: ""
    };
  },
  getters: {
    isLogin: (state) => !!state.accessToken,
    currentUserInfo(state) {
      if (!state.userInfo.length)
        return;
      if (state.currentUserId) {
        return state.userInfo.find((item) => {
          return item.userId == state.currentUserId;
        });
      }
      return state.userInfo[0];
    }
  },
  actions: {
    // 根据验证码登录
    async loginBySms(data) {
      const { phone, code } = data;
      const res = await service_modules_login.loginBySms(phone, code);
      this.accessToken = res.access_token;
      return await this.getUserInfoByCode();
    },
    // 根据账号密码登录
    async loginByPassword(data) {
      const { phone, password } = data;
      const res = await service_modules_login.loginByPassword(phone + "@mp", password);
      return res;
    },
    // 获取用户信息
    async getUserInfoByCode() {
      const wxLoginRes = await service_modules_common.login();
      const wxUserInfo = await service_modules_common.getUserInfo();
      const wxCode = wxLoginRes.code;
      const res = await service_modules_newsDetail.getOpenId(wxCode);
      const userInfoData = await service_modules_login.getUserInfoByCode(
        res.openid,
        encodeURIComponent(wxUserInfo.userInfo.avatarUrl)
      );
      this.userInfo = userInfoData.data.userInfo;
      return userInfoData.data;
    },
    // 更换当前的企业
    setCurrentUserId(id) {
      this.currentUserId = id;
    },
    async changeWeiXinLogin(sendParams) {
      const res = await service_modules_login.changeEnt(sendParams);
      this.accessToken = res.access_token;
      return await this.getUserInfoByCode();
    },
    // 退出登录
    logoutFn() {
      service_modules_login.logoutApi();
    }
  },
  persist: {
    storage: {
      getItem(key) {
        return common_vendor.index.getStorageSync(key);
      },
      setItem(key, value) {
        return common_vendor.index.setStorageSync(key, value);
      }
    }
  }
});
exports.useLoginStore = useLoginStore;
