"use strict";
function isValidPhoneNumber(phoneNumber) {
  const regex = /^1[3456789]\d{9}$/;
  return regex.test(phoneNumber);
}
function isValidBankCard(phoneNumber) {
  const regex = /^([1-9]{1})(\d{15}|\d{18})$/;
  return regex.test(phoneNumber);
}
function validateEmail(email) {
  const regex = /^[a-zA-Z0-9._-]+@[a-zA-Z0-9.-]+\.[a-zA-Z]{2,4}$/;
  return regex.test(email);
}
function isValidChineseIDNumber(idNumber) {
  const idRegex = /^[1-9]\d{5}(19\d{2}|20\d{2})((0[1-9]|1[0-2])(0[1-9]|[12]\d|3[01])|[1-9]\d{3})(\d{3}[0-9Xx])$/;
  if (!idRegex.test(idNumber)) {
    return false;
  }
  const weightFactors = [7, 9, 10, 5, 8, 4, 2, 1, 6, 3, 7, 9, 10, 5, 8, 4, 2];
  const checkCodeMap = ["1", "0", "X", "9", "8", "7", "6", "5", "4", "3", "2"];
  const digits = idNumber.slice(0, 17);
  let sum = 0;
  for (let i = 0; i < 17; i++) {
    sum += parseInt(digits[i], 10) * weightFactors[i];
  }
  const mod = sum % 11;
  const checkCode = checkCodeMap[mod];
  return idNumber[17].toUpperCase() === checkCode;
}
function debounce(func, delay = 500) {
  let timer = null;
  return function(...args) {
    if (timer)
      clearTimeout(timer);
    timer = setTimeout(() => {
      func.apply(this, args);
    }, delay);
  };
}
const formatRichTxt = (str) => {
  let htmlStr = str.replace(/<.*?>/g, "");
  htmlStr = htmlStr.replace(/(\n)/g, "");
  htmlStr = htmlStr.replace(/(\t)/g, "");
  htmlStr = htmlStr.replace(/(\r)/g, "");
  htmlStr = htmlStr.replace(/<\/?[^>]*>/g, "");
  htmlStr = htmlStr.replace(/\s*/g, "");
  return htmlStr.replace(/&(lt|gt|nbsp|amp|quot);/gi, "");
};
const EARTH_RADIUS = 6378.137;
function rad(d) {
  return d * Math.PI / 180;
}
const getDistance = (lng1, lat1, lng2, lat2) => {
  const radLat1 = rad(lat1);
  const radLat2 = rad(lat2);
  const a = radLat1 - radLat2;
  const b = rad(lng1) - rad(lng2);
  let s = 2 * Math.asin(
    Math.sqrt(
      Math.pow(Math.sin(a / 2), 2) + Math.cos(radLat1) * Math.cos(radLat2) * Math.pow(Math.sin(b / 2), 2)
    )
  );
  s = s * EARTH_RADIUS;
  s = Math.round(s * 1e4) / 1e4;
  return s;
};
const transformContentToMultiLineText = (ctx, text, contentWidth, lineNumber) => {
  const textArray = text.split("");
  let temp = "";
  let row = [];
  for (let i = 0; i < textArray.length; i++) {
    if (ctx.measureText(temp).width < contentWidth) {
      temp += textArray[i];
    } else {
      i--;
      row.push(temp);
      temp = "";
    }
  }
  row.push(temp);
  if (row.length > lineNumber) {
    if (!lineNumber || lineNumber == 1) {
      row[0] += "...";
    } else {
      const rowCut = row.slice(0, lineNumber);
      const rowPart = rowCut[1];
      let test = "";
      const empty = [];
      for (let a = 0; a < rowPart.length; a++) {
        if (ctx.measureText(test).width < contentWidth) {
          test += rowPart[a];
        } else {
          break;
        }
      }
      empty.push(test);
      const group = empty[0] + "...";
      rowCut.splice(lineNumber - 1, 1, group);
      row = rowCut;
    }
  }
  console.log("row", row);
  return row;
};
exports.debounce = debounce;
exports.formatRichTxt = formatRichTxt;
exports.getDistance = getDistance;
exports.isValidBankCard = isValidBankCard;
exports.isValidChineseIDNumber = isValidChineseIDNumber;
exports.isValidPhoneNumber = isValidPhoneNumber;
exports.transformContentToMultiLineText = transformContentToMultiLineText;
exports.validateEmail = validateEmail;
