"use strict";
const common_vendor = require("../common/vendor.js");
const getWxLocationApi = (type) => {
  return new Promise(function(resolve, reject) {
    common_vendor.index.getLocation({
      type: type || "gcj02",
      success(res) {
        resolve(res);
      },
      fail(e) {
        getSettingApi(reject, e);
      }
    });
  });
};
function getSettingApi(reject, e) {
  common_vendor.index.getSetting({
    success(res) {
      if (!res.authSetting["scope.userLocation"]) {
        showModalApi(reject, e);
      }
    },
    fail(err) {
      common_vendor.index.showModal({
        title: "错误提示",
        content: err || e || "获取配置信息错误，请检查定位是否开启"
      });
    }
  });
}
function showModalApi(reject, e) {
  common_vendor.index.showModal({
    title: "友情提示",
    content: "小程序需要获取您的定位功能才可使用",
    success: function(res) {
      if (res.confirm) {
        common_vendor.index.openSetting({
          success(res2) {
            console.log("openSetting", res2.authSetting);
          },
          fail(err) {
            common_vendor.index.showModal({
              title: "错误提示",
              content: err || "打开配置信息错误，请检查定位是否开启"
            });
          }
        });
      } else if (res.cancel) {
        reject(e);
        console.log("openSettingError", res);
      }
    }
  });
}
const downloadFile = (url) => {
  const promise = new Promise(function(resolve, reject) {
    common_vendor.index.downloadFile({
      url,
      //仅为示例，并非真实的资源
      success: (res) => {
        if (res.statusCode === 200) {
          resolve(res);
        } else {
          reject(res);
        }
      },
      fail: (e) => {
        reject(e);
      }
    });
  });
  return promise;
};
const getSystemInfo = async () => {
  try {
    const res = await common_vendor.index.getSystemInfoSync();
    res.toPx = res.windowWidth / 750;
    return res;
  } catch (error) {
    console.log("error", error);
  }
};
const saveImageToPhotosAlbum = (path) => {
  const promise = new Promise(function(resolve, reject) {
    common_vendor.index.saveImageToPhotosAlbum({
      filePath: path,
      success: function() {
        resolve(true);
      },
      fail: function(e) {
        reject(e);
      }
    });
  });
  return promise;
};
exports.downloadFile = downloadFile;
exports.getSystemInfo = getSystemInfo;
exports.getWxLocationApi = getWxLocationApi;
exports.saveImageToPhotosAlbum = saveImageToPhotosAlbum;
